.. image:: https://travis-ci.org/enyx-opensource/yassh.svg?branch=master
   :target: https://travis-ci.org/enyx-opensource/yassh
   :alt: Build Status

.. image:: https://coveralls.io/repos/github/enyx-opensource/yassh/badge.svg?branch=master
   :target: https://coveralls.io/github/enyx-opensource/yassh?branch=master
   :alt: Coverage Status

.. image:: https://codeclimate.com/github/enyx-opensource/yassh/badges/gpa.svg
   :target: https://codeclimate.com/github/enyx-opensource/yassh
   :alt: Code Climate

.. image:: https://codeclimate.com/github/enyx-opensource/yassh/badges/issue_count.svg
   :target: https://codeclimate.com/github/enyx-opensource/yassh
   :alt: Issue Count

.. image:: https://readthedocs.org/projects/yassh/badge/?version=latest
  :target: http://yassh.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

yassh
=====

Yassh is a python library used to run 
asynchronous, dependent remote and local tasks.

Usage
-----

.. literalinclude:: ../examples/overview.py

Installation
------------

To install latest release::

    pip install yassh

To install latest code::

    pip install git+https://github.com/enyx-opensource/yassh.git

Testing
-------

Run from project root::

    behave

License
-------
MIT License (see LICENSE)

